# Toy LLM

ToyLLM is a simple language model that can be used to generate text.
It is based on the [GPT-2](https://huggingface.co/transformers/model_doc/gpt2.html) model.


# Acknowledgements
The project is highly inspired by the following projects:
- [rasbt/LLMs-from-scratch](https://github.com/rasbt/LLMs-from-scratch)
- [neelnanda-io/TransformerLens](https://github.com/neelnanda-io/TransformerLens)
